/***********************************************************************
 *         Copyright (C) 2000 Advanced Rotorcraft Technology Inc.      *
 *                      All rights reserved                            *
 ***********************************************************************
 *
 * File: 	demoutils.c
 * Description:	Miscellaneous utilities for demo C programs. 
 *
 * $Id: demoutils.c,v 1.2 2000/10/02 20:50:18 joe Exp $
 */


#include <stdlib.h>
#include <signal.h>
#include <time.h>
#include "demoutils.h"

/* 
 * trap_interrupts() --
 *	Sets up a signal handler to catch SIGINT (keyboard Control-C)
 */

static volatile sig_atomic_t interrupt_flag = 0;
static void sigint_handler()
{
	interrupt_flag = 1;
}

void trap_interrupts(void)
{
    struct sigaction act;
    act.sa_flags = 0;
    act.sa_handler = sigint_handler;
    sigfillset(&act.sa_mask);
    sigaction(SIGINT, &act, NULL);
}

/* interrupted() --
 *	Returns 1 if an interrupt signal has been received,
 *	0 otherwise.
 */
int interrupted(void) 
{
    return interrupt_flag;
}

/* clear_interrupts() --
 *	Clears the interrupted() flag.
 */
void clear_interrupts(void)
{
    interrupt_flag = 0;
}


/*
 * millisleep(ms) --
 *	Sleep for 'ms' milliseconds.
 */
void millisleep(unsigned long ms)
{
    struct timespec tm;
    tm.tv_sec  = ms / 1000;
    tm.tv_nsec = (ms % 1000) * 1000000L;
    nanosleep(&tm, NULL);
}

/*EOF*/
