/* 
 * $Id: flcomms-example.c,v 1.2 2000/12/27 21:16:45 luther Exp $
 *
 * Example of how to use the FLCOMMS C language API
 * to interface with a FLIGHTLAB model running under Scope.
 */


#include <stdlib.h>
#include <stdio.h>
#include <errno.h>
#include <string.h>

#include "demoutils.h"
#include "flcomms.h"
#include "flcomms-example.h"

int main(int argc, char *argv[])
{
    char *errmessage = "";
    int status;
    FLC_HANDLE bodystates_handle;
    BODYSTATES bodystates;

    /* 
     * Set up a signal handler to catch ^C:
     */
    trap_interrupts();

    /*
     * Attach to the FLCOMMS shared memory block:
     */
    status = flc_attach(NULL, 0);
    if (status < 0) { errmessage = "flc_attach"; goto error; }

    /*
     * Open the data block:
     */
    bodystates_handle = flc_open(
    	"BODYSTATES",				/* name */
	sizeof(BODYSTATES),			/* size */
	FLCOMMS_BODYSTATES_MAGIC,		/* magic */
	FLC_MODE_READ | FLC_TYPE_DOUBLE 	/* flags */
    );
    if (!bodystates_handle) { errmessage = "flc_open"; goto error; }

    printf("Polling...  Press ^C to quit.\n");
    while (!interrupted()) 
    {
    	millisleep(250);
	if (!flc_ready(bodystates_handle))
		continue;

	flc_read(bodystates_handle, &bodystates, sizeof(bodystates));

	fprintf(stdout, "%POS: %8.4f %8.4f %8.4f; ROT: %6.3f %6.3f %6.3f\r",
		bodystates.posxi, bodystates.posyi, bodystates.poszi,
		bodystates.phi,   bodystates.theta, bodystates.psi);
	fflush(stdout);
    }
    printf("\nDone.\n");

    /*
     * Clean up.
     * Note that it is not necessary to call flc_close(bodystates_handle)
     * at this point, since since flc_detach() will automatically close
     * all open handles.
     */

    flc_detach();
    return EXIT_SUCCESS;

error:
    fprintf(stderr, "%s: error in %s (%s)\n", 
    	argv[0], errmessage, strerror(errno));
    return EXIT_FAILURE;
}

/*EOF*/
